@@ -1,5 +1,7 @@
 #!/usr/bin/snimpy
 
+from __future__ import print_function
+
 import os
 import sys
 
@@ -15,8 +17,8 @@ s = M(host=sys.argv[1], community=sys.argv[2])
 try:
     cur = s.rcVlanName[vlanNumber]
 except snmp.SNMPException:
-    print "%s is not a Nortel switch or does not have VLAN %d" % (sys.argv[1], vlanNumber)
+    print("%s is not a Nortel switch or does not have VLAN %d" % (sys.argv[1], vlanNumber))
     sys.exit(1)
 if cur != newName:
     s.rcVlanName[vlanNumber] = newName
-print "Setting VLAN %d of %s as %s: done." % (vlanNumber, sys.argv[1], newName)
+print("Setting VLAN %d of %s as %s: done." % (vlanNumber, sys.argv[1], newName))
