@@ -88,7 +88,7 @@ class TestManagerGet(TestManager):
 
     def testScalar_Bits(self):
         """Retrieve Bits as a scalar"""
-        self.scalarGetAndCheck("snimpyBits", ["first", "third"])
+        self.scalarGetAndCheck("snimpyBits", ["first", "third", "secondByte"])
 
     def testScalar_MacAddress(self):
         """Retrieve MacAddress as a scalar"""
@@ -120,6 +120,10 @@ class TestManagerGet(TestManager):
                           (2, "eth0", 6),
                           (3, "eth1", 6)])
 
+    def testWalkNotAccessible(self):
+        """Test we can walk a table with the first entry not accessible."""
+        list(self.manager.ifRcvAddressTable)
+
     def testWalkIfDescrWithoutBulk(self):
         """Walk IF-MIB::ifDescr without GETBULK"""
         self.session.bulk = False
@@ -154,6 +158,22 @@ class TestManagerGet(TestManager):
                           (("row3", (120, 1, 2, 3),
                             "gamma7", "end of row3"), 4110)])
 
+    def testWalkReuseIndexes(self):
+        """Test if we can walk a table with re-used indexes"""
+        results = [(idx, self.manager.snimpyReuseIndexValue[idx])
+                   for idx in self.manager.snimpyReuseIndexValue]
+        self.assertEqual(results,
+                         [(("end of row1", 4), 1785),
+                          (("end of row1", 5), 2458)])
+
+    def testWalkTableWithReuseIndexes(self):
+        """Test if we can walk a table with re-used indexes"""
+        results = [(idx, self.manager.snimpyReuseIndexValue[idx])
+                   for idx in self.manager.snimpyReuseIndexTable]
+        self.assertEqual(results,
+                         [(("end of row1", 4), 1785),
+                          (("end of row1", 5), 2458)])
+
     def testWalkPartialIndexes(self):
         """Test if we can walk a slice of a table given a partial index"""
         results = [(idx, self.manager.ifRcvAddressType[idx])
@@ -318,7 +338,7 @@ class TestManagerSet(TestManager):
 
     def testScalar_Bits(self):
         """Retrieve Bits as a scalar"""
-        self.scalarSetAndCheck("snimpyBits", ["first", "second"])
+        self.scalarSetAndCheck("snimpyBits", ["first", "second", "secondByte"])
 
     def testScalar_MacAddress(self):
         """Retrieve MAC address as a scala"""
