@@ -23,7 +23,8 @@ class TestMibSnimpy(unittest.TestCase):
                        "snimpySimpleTable",
                        "snimpyIndexTable",
                        "snimpyInvalidTable",
-                       "snimpyEmptyTable"]
+                       "snimpyEmptyTable",
+                       "snimpyReuseIndexTable"]
         self.tables.sort()
         self.columns = ["snimpyComplexFirstIP",
                         "snimpyComplexSecondIP",
@@ -44,7 +45,8 @@ class TestMibSnimpy(unittest.TestCase):
                         "snimpyInvalidIndex",
                         "snimpyInvalidDescr",
                         "snimpyEmptyIndex",
-                        "snimpyEmptyDescr"
+                        "snimpyEmptyDescr",
+                        "snimpyReuseIndexValue"
                         ]
         self.columns.sort()
         self.scalars = ["snimpyIpAddress",
@@ -257,7 +259,8 @@ class TestMibSnimpy(unittest.TestCase):
                          {0: "first",
                           1: "second",
                           2: "third",
-                          7: "last"})
+                          7: "last",
+                          8: "secondByte"})
 
     def testIndexes(self):
         """Test that we can retrieve correctly the index of tables"""
